@@ -27,7 +27,7 @@
 
 #include <QTest>
 #include <QSignalSpy>
-#include <QtTest/qsignalspy.h>
+#include <qsignalspy.h>
 
 void ManagerTest::initTestCase()
 {
@@ -68,6 +68,26 @@ void ManagerTest::testDevices()
     QVERIFY(NetworkManager::networkInterfaces().isEmpty());
     QCOMPARE(removeDeviceSpy.at(0).at(0).toString(), addedDevicePath);
 
+    addDeviceSpy.clear();
+
+    fakeNetwork->addDevice(device);
+    QVERIFY(addDeviceSpy.wait());
+    QCOMPARE(NetworkManager::networkInterfaces().count(), 1);
+    QCOMPARE(NetworkManager::networkInterfaces().first()->uni(), addDeviceSpy.at(0).at(0).toString());
+
+    addDeviceSpy.clear();
+    removeDeviceSpy.clear();
+
+    fakeNetwork->unregisterService();
+    QTRY_COMPARE(removeDeviceSpy.count(), 1);
+
+    fakeNetwork->registerService();
+    QTRY_COMPARE(addDeviceSpy.count(), 1);
+
+    // Make sure deviceAdded is emitted only once
+    addDeviceSpy.wait(100);
+    QCOMPARE(addDeviceSpy.count(), 1);
+
     delete device;
 }
 
@@ -115,7 +135,6 @@ void ManagerTest::testManager()
     QVERIFY(wirelessHwEnabledChanged.at(0).at(0).toBool() == false);
     QCOMPARE(NetworkManager::isWirelessHardwareEnabled(), false);
 
-#if !NM_CHECK_VERSION(1, 2, 0)
     QSignalSpy wimaxEnabledChanged(NetworkManager::notifier(), SIGNAL(wimaxEnabledChanged(bool)));
     QCOMPARE(NetworkManager::isWimaxEnabled(), true);
     fakeNetwork->setWimaxEnabled(false);
@@ -131,7 +150,6 @@ void ManagerTest::testManager()
     QCOMPARE(wimaxHwEnabledChanged.count(), 1);
     QVERIFY(wimaxHwEnabledChanged.at(0).at(0).toBool() == false);
     QCOMPARE(NetworkManager::isWimaxHardwareEnabled(), false);
-#endif
 
     QSignalSpy wwanEnabledChanged(NetworkManager::notifier(), SIGNAL(wwanEnabledChanged(bool)));
     QCOMPARE(NetworkManager::isWwanEnabled(), true);
@@ -144,10 +162,8 @@ void ManagerTest::testManager()
     // We make it here, so we can set all values back for futher testing
     fakeNetwork->setWirelessEnabled(true);
     fakeNetwork->setWirelessHardwareEnabled(true);
-#if !NM_CHECK_VERSION(1, 2, 0)
     fakeNetwork->setWimaxEnabled(true);
     fakeNetwork->setWimaxHardwareEnabled(true);
-#endif
     fakeNetwork->setWwanEnabled(true);
 }
 
